# Change History

## 2022.8.2

* Fixed first and third party software documentation
* Added link to todos
* Migrated away from github
* Added link to test coverage documentation

## 2022.7.17

* Maintenance release with updates in test and dev dependencies as well as type and test fixes

## Older

### 2019.10.19 (0.0.1)

* Initial version on PyPI
